/*******************
VARIABLES
*******************/
var lastModified = "2018-08-16";
var lastUploaded = "2018-08-16";

var templateVersion = "2.0.24";
var dimensions;
var scrollPos = {
	x: 0,
	y: 0
};

var expansionDiv;
var closeButton;
var userActionButton;
var clickthroughButton;
var sdkData;
var adId, rnd, uid;
var videoActive = false;
var videoAction = "paused";
var trackedVideo;
var video;
var videoContainer;
var videoIsPlaying;
var userPauseFlag;
var firstTimeVisible = false;
var visibleState;
var isFullscreen;
var hideBanner;
var visibilityThreshold;
var isSamsungBrowser = false;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
		if (window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
			initializeCreative();
			return;
		}
	}
	catch (e) {}

	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {
	isSamsungBrowser = EB.API.os.uahas('SamsungBrowser');
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function () {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function () {
		eventManager.apply(this, arguments);
	}, this);

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);

	initializeGlobalVariables();
	window.registerInteraction = function () {}; //overwrite rI function because it will never actually be called
	initializeCloseButton();

	// displayDimensions();
	addEventListeners();

}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	visibilityThreshold = EB.API.getCustomVar("mdVisibilityThreshold");
	hideBanner = EB.API.getCustomVar("mdHideBanner");
	expansionDiv = document.getElementById("expansion");
	closeButton = document.getElementById("closeButton");
	dimensions = document.getElementById("dimensions"); //for testing only, show the dimensions and scrollpos of the parent
	userActionButton = document.getElementById("userActionButton");
	clickthroughButton = document.getElementById("clickthroughButton");
	videoContainer = document.getElementById("videoContainer");
	video = document.getElementById("video");

	initializeVideo(video);
	sdkData = EB.getSDKData();
}

function initializeCloseButton() {
	var enableSDKDefaultCloseButton = EB._adConfig && EB._adConfig.hasOwnProperty("mdEnableSDKDefaultCloseButton") && EB._adConfig.mdEnableSDKDefaultCloseButton;
	if (sdkData !== null) {
		if (sdkData.SDKType === "MRAID" && !enableSDKDefaultCloseButton) {
			// set sdk to use custom close button
			EB.setExpandProperties({
				useCustomClose: true
			});
		}
	}
}

function initializeVideo(video) {
	trackedVideo = new EBG.VideoModule(video);
	EB.API.setStyle(videoContainer, {visibility: "visible"});

	if (EB.API.os.ios) {
		if (EB.API.os.ver >= 10) {
			video.setAttribute("playsinline", ""); // iOS 10 new playsinline attribute enable vidoe plays in line (muted)
		}
	}

}

function addEventListeners() {
	closeButton.addEventListener("click", handleCloseButtonClick);
	userActionButton.addEventListener("click", handleUserActionButtonClick);
	clickthroughButton.addEventListener("click", handleClickthroughButtonClick);
	video.addEventListener("play", handlePlayButtonClicked, false);
	video.addEventListener("pause", handlePauseButtonClicked, false);
	expansionDiv.addEventListener("mouseover", handleMouseOver, false);
	video.addEventListener('webkitfullscreenchange', onFullScreen);
	video.addEventListener('mozfullscreenchange', onFullScreen);
	video.addEventListener('fullscreenchange', onFullScreen);
	expansionDiv.addEventListener("touchstart", handleMouseOver, false);
	video.addEventListener("touchstart", handleMouseOver, false);
}

/*******************
EVENT HANDLERS
*******************/

function showButtons() {
	EB.API.setStyle(closeButton, {visibility: "visible"});
	EB.API.setStyle(userActionButton, {visibility: "visible"});
	EB.API.setStyle(clickthroughButton, {visibility: "visible"});
}

function hideButtons() {
	EB.API.setStyle(closeButton, {visibility: "hidden"});
	EB.API.setStyle(userActionButton, {visibility: "hidden"});
	EB.API.setStyle(clickthroughButton, {visibility: "hidden"});
}

function animationStarted() {
	hideButtons();
	EB.API.removeClass(video, ["showVideo"]);
	EB.API.setClass(video, ["hideVideo"]);
}

function animationComplete() {
	EB.API.setStyle(closeButton, {display: "block"});
	showButtons();
	EB.API.removeClass(video, ["hideVideo"]);
	EB.API.setClass(video, ["showVideo"]);
}

function onFullScreen(obj) {

	if (obj.ieCompatable) {
		isFullscreen = obj.fs;
	}
	else {

		if (document.fullscreenElement || document.webkitFullscreenElement || document.mozFullScreenElement) {
			isFullscreen = true;
		}
		else {
			isFullscreen = false;
		}
	}

	dispatchCustomScriptEvent("isFullscreen", {
		state: isFullscreen
	});

}

function handleMouseOver(event) {
	dispatchCustomScriptEvent("mouseOver");
}

function handlePlayButtonClicked(event) {
	videoActive = true;
}

function handlePauseButtonClicked(event) {
	if (videoAction == "paused") return;
	videoActive = false;
}

function handleCloseButtonClick() {
	EB.API.setStyle(closeButton, {display: "none"});
	videoActive = false;
	pauseVideo();
	dispatchCustomScriptEvent("closePanel");
}

function handleUserActionButtonClick() {
	EB.userActionCounter("CustomInteraction");
}

function handleClickthroughButtonClick() {
	EB.clickthrough();
	pauseVideo();
}

function onPageScroll(event) {
	scrollPos.x = event.scrollXPercent;
	scrollPos.y = event.scrollYPercent;
	// displayDimensions();
	checkVideoState();

	//isFullscreen workaround for IE browsers
	if (EB.API.browser.ie && EB.API.browser.ver == 10 || EB.API.browser.ver == 11) {

		if (window.outerWidth === screen.width && window.outerHeight === screen.height) {
			if (!isFullscreen) {
				isFullscreen = true;
				onFullScreen({
					fs: true,
					ieCompatable: true
				});
			}
		}
		else {
			if (isFullscreen) {
				isFullscreen = false;
				onFullScreen({
					fs: false,
					ieCompatable: true
				});
			}
		}
	}
}

/*******************
UTILITIES
*******************/

function displayDimensions() {
	if (dimensions) {
		var iw = window.innerWidth,
			ih = window.innerHeight,
			sx = scrollPos.x,
			sy = scrollPos.y;
		var str = "<br>Viewport: " + iw + "x" + ih + " | <span style='display:block'>Scroll (X: " + sx + "%; Y: " + sy + "%)</span>";
		dimensions.innerHTML = str;
	}
}

function visibilityState(event) {
	if (isFullscreen) return;
	if (isSamsungBrowser) return;

	if (event.isVisible) {
		showButtons();
		EB.API.removeClass(video, ["hideVideo"]);
		EB.API.setClass(video, ["showVideo"]);
		if (visibleState) return;

		visibleState = true;
		if (visibilityThreshold == -1) EB.API.setStyle(closeButton, {display: "block"});
		else EB.API.setStyle(closeButton, {display: "none"});

		if (!hideBanner) {
			pauseVideo();
			return;
		}
		if (!videoIsPlaying && !firstTimeVisible) {
			firstTimeVisible = true;
		}

		if (!videoActive) return;

		if (event.collapseCalled && video.paused) {
			videoAction = "play";
			video.play();
		}

	}
	else {

		if (visibleState === false) return;

		visibleState = false;
		if (!hideBanner) {
			if (!videoIsPlaying && !firstTimeVisible) {
				firstTimeVisible = true;
			}
		}
		if (!event.collapseCalled) EB.API.setStyle(closeButton, {display: "block"});

		if (!videoActive) return;

		if (event.collapseCalled && !video.paused) {
			videoAction = "paused";
			pauseVideo();
		}

	}

}

function checkVideoState() {
	if (!video.paused) videoIsPlaying = true;
	else videoIsPlaying = false;

}

function pauseVideo() {
	if (video) {
		video.pause();
		userPauseFlag = true;
		videoIsPlaying = false;

	}
}

function collapse() {
	handleCloseButtonClick();
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {

	if (!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {

	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);

	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			addCustomScriptEventListener("visibilityState", visibilityState);
			addCustomScriptEventListener('pageScroll', onPageScroll);
			addCustomScriptEventListener('animationStarted', animationStarted);
			addCustomScriptEventListener('animationComplete', animationComplete);
			sendMessage("dispatchScrollPos", {
				uid: uid
			});
			if (creativeContainerReady)
				creativeContainerReady();
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for (var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if (!t) continue;
					t.callback(msg.data);
				}
				catch (e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function () {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);