/*******************
VARIABLES
*******************/
var creativeId = "Banner";
var creativeVersion = "1.0.2";
var lastModified = "2018-08-16";
var lastUploaded = "2018-08-16";

var templateVersion = "2.0.24";
var dimensions;
var scrollPos = {
	x: 0,
	y: 0
};

var bannerDiv;
var expandButton;
var sdkData;
var adId, rnd, uid;
var isVisible;
var collapseCalled = false;
var visibilityThreshold;
var visiblePerecent;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
		if (window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
			initializeCreative();
			return;
		}
	}
	catch (e) {}

	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {

	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function () {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function () {
		eventManager.apply(this, arguments);
	}, this);

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);

	initializeGlobalVariables();
	window.registerInteraction = function () {}; //overwrite rI function because it will never actually be called
	addEventListeners();
	displayDimensions();

	setCreativeVersion();

}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	bannerDiv = document.getElementById("banner");
	expandButton = document.getElementById("expandButton");
	dimensions = document.getElementById("dimensions"); //for testing only, show the dimensions and scrollpos of the parent
	sdkData = EB.getSDKData();
	visibilityThreshold = EB.getCustomVar("mdVisibilityThreshold");
}

function addEventListeners() {
	//expandButton.addEventListener("click", handleExpandButtonClick);
}

function registerInteraction() {
	//Register your automatic and user interactions here and the platform will parse them on workspace upload. This function will not be called.
	//Example: 'Left_Gutter_Viewed'
	//EB.automaticEventCounter("interactionName1");
	//EB.automaticEventCounter("interactionName2");

	//EB.userActionCounter("userActionName1");
	//EB.userActionCounter("userActionName2");
}

/*******************
EVENT HANDLERS
*******************/

function handleVisibility(bannerVisibility) {
	var isVisiblePerecent = bannerVisibility;

	if (isVisiblePerecent === undefined) {
		dispatchCustomScriptEvent("getScroll");
		return;
	}
	if (isVisiblePerecent <= visibilityThreshold) {
		if (!isVisible) return;
		isVisible = false;
		dispatchVisibilityState();
	}
	else {
		if (isVisible) return;
		isVisible = true;
		dispatchVisibilityState();
	}

}

function dispatchVisibilityState() {
	if ((EB.API.browser.ie && EB.API.browser.ver == 10) || (EB.API.browser.ie && EB.API.browser.ver == 11) || EB.API.os.android) {
		setTimeout(function () {
			dispatchCustomScriptEvent("visibilityState", {
				isVisible: isVisible,
				collapseCalled: collapseCalled
			});
		}, 150);
	}
	else {
		dispatchCustomScriptEvent("visibilityState", {
			isVisible: isVisible,
			collapseCalled: collapseCalled
		});
	}
}

function onPageScroll(event) {

	scrollPos.x = event.scrollXPercent;
	scrollPos.y = event.scrollYPercent;
	displayDimensions();
	handleVisibility(event.bannerVisibility);
}

function onCollapse(event) {

	collapseCalled = true;
	dispatchCustomScriptEvent("visibilityState", {
		isVisible: true,
		collapseCalled: collapseCalled
	});

}

/*******************
UTILITIES
*******************/

function displayDimensions() {
	if (dimensions) {
		var iw = window.innerWidth,
			ih = window.innerHeight,
			sx = scrollPos.x,
			sy = scrollPos.y;
		var str = "<br>Viewport: " + iw + "x" + ih + " | <span style='display:block'>Scroll (X: " + sx + "%; Y: " + sy + "%)</span>";
		dimensions.innerHTML = str;
	}
}

function setCreativeVersion() {
	sendMessage("setCreativeVersion", {
		creativeId: creativeId,
		creativeVersion: creativeVersion,
		creativeLastModified: lastModified,
		uid: uid
	});
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if (!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if (listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {

	var msg;
	if (typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);

	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if (msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch (msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			addCustomScriptEventListener('closePanel', onCollapse);
			addCustomScriptEventListener('pageScroll', onPageScroll);
			sendMessage("dispatchScrollPos", {
				uid: uid
			});
			if (creativeContainerReady)
				creativeContainerReady();
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for (var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if (!t) continue;
					t.callback(msg.data);
				}
				catch (e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function () {
	try {
		eventManager.apply(this, arguments);
	}
	catch (e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);